# Littleloop API Documentation

## Base URL
```
http://your-domain.com/api
```

## Authentication
The API uses Laravel Sanctum for authentication. Some endpoints require authentication using a Bearer token.

### Getting a Token
To get an authentication token, you need to either register or login.

#### Register
```http
POST /register
Content-Type: application/json

{
    "name": "string",
    "email": "string",
    "password": "string",
    "password_confirmation": "string",
    "phone": "string",
    "address": "string"
}

Response:
{
    "data": {
        "user": {
            "id": number,
            "name": "string",
            "email": "string",
            "phone": "string",
            "address": "string",
            "created_at": "datetime",
            "updated_at": "datetime"
        },
        "token": "string"
    },
    "message": "User registered successfully"
}
```

#### Login
```http
POST /login
Content-Type: application/json

{
    "email": "string",
    "password": "string"
}

Response:
{
    "data": {
        "user": {
            "id": number,
            "name": "string",
            "email": "string",
            "phone": "string",
            "address": "string",
            "created_at": "datetime",
            "updated_at": "datetime"
        },
        "token": "string"
    },
    "message": "User logged in successfully"
}
```

#### Logout (Requires Authentication)
```http
POST /logout
Authorization: Bearer {token}

Response:
{
    "message": "User logged out successfully"
}
```

## Products

### List Products
```http
GET /products
Query Parameters:
- category_id (optional): Filter by category
- featured (optional): Filter featured products
- search (optional): Search in name_en and name_ar

Response:
{
    "data": {
        "current_page": number,
        "data": [
            {
                "id": number,
                "name_en": "string",
                "name_ar": "string",
                "description_en": "string",
                "description_ar": "string",
                "category": {
                    "id": number,
                    "name_en": "string",
                    "name_ar": "string",
                    "description_en": "string",
                    "description_ar": "string",
                    "created_at": "datetime",
                    "updated_at": "datetime"
                },
                "variations": [
                    {
                        "id": number,
                        "size": "string",
                        "color": "string",
                        "price": number,
                        "stock": number,
                        "created_at": "datetime",
                        "updated_at": "datetime"
                    }
                ],
                "images": [
                    {
                        "id": number,
                        "url": "string",
                        "is_primary": boolean,
                        "created_at": "datetime",
                        "updated_at": "datetime"
                    }
                ],
                "created_at": "datetime",
                "updated_at": "datetime"
            }
        ],
        "first_page_url": "string",
        "from": number,
        "last_page": number,
        "last_page_url": "string",
        "next_page_url": "string",
        "path": "string",
        "per_page": number,
        "prev_page_url": "string",
        "to": number,
        "total": number
    },
    "message": "Products retrieved successfully"
}
```

### Get Single Product
```http
GET /products/{product_id}

Response:
{
    "data": {
        "id": number,
        "name_en": "string",
        "name_ar": "string",
        "description_en": "string",
        "description_ar": "string",
        "category": {
            "id": number,
            "name_en": "string",
            "name_ar": "string",
            "description_en": "string",
            "description_ar": "string",
            "created_at": "datetime",
            "updated_at": "datetime"
        },
        "variations": [
            {
                "id": number,
                "size": "string",
                "color": "string",
                "price": number,
                "stock": number,
                "created_at": "datetime",
                "updated_at": "datetime"
            }
        ],
        "images": [
            {
                "id": number,
                "url": "string",
                "is_primary": boolean,
                "created_at": "datetime",
                "updated_at": "datetime"
            }
        ],
        "created_at": "datetime",
        "updated_at": "datetime"
    },
    "message": "Product retrieved successfully"
}
```

### Get Featured Products
```http
GET /products/featured

Response:
{
    "data": [
        {
            "id": number,
            "name_en": "string",
            "name_ar": "string",
            "description_en": "string",
            "description_ar": "string",
            "category": {
                "id": number,
                "name_en": "string",
                "name_ar": "string",
                "description_en": "string",
                "description_ar": "string",
                "created_at": "datetime",
                "updated_at": "datetime"
            },
            "variations": [
                {
                    "id": number,
                    "size": "string",
                    "color": "string",
                    "price": number,
                    "stock": number,
                    "created_at": "datetime",
                    "updated_at": "datetime"
                }
            ],
            "images": [
                {
                    "id": number,
                    "url": "string",
                    "is_primary": boolean,
                    "created_at": "datetime",
                    "updated_at": "datetime"
                }
            ],
            "created_at": "datetime",
            "updated_at": "datetime"
        }
    ],
    "message": "Featured products retrieved successfully"
}
```

## Categories

### List Categories
```http
GET /categories

Response:
{
    "data": [
        {
            "id": number,
            "name_en": "string",
            "name_ar": "string",
            "description_en": "string",
            "description_ar": "string",
            "created_at": "datetime",
            "updated_at": "datetime"
        }
    ],
    "message": "Categories retrieved successfully"
}
```

### Get Single Category with Products
```http
GET /categories/{category_id}

Response:
{
    "data": {
        "id": number,
        "name_en": "string",
        "name_ar": "string",
        "description_en": "string",
        "description_ar": "string",
        "products": [
            {
                "id": number,
                "name_en": "string",
                "name_ar": "string",
                "description_en": "string",
                "description_ar": "string",
                "variations": [
                    {
                        "id": number,
                        "size": "string",
                        "color": "string",
                        "price": number,
                        "stock": number,
                        "created_at": "datetime",
                        "updated_at": "datetime"
                    }
                ],
                "images": [
                    {
                        "id": number,
                        "url": "string",
                        "is_primary": boolean,
                        "created_at": "datetime",
                        "updated_at": "datetime"
                    }
                ],
                "created_at": "datetime",
                "updated_at": "datetime"
            }
        ],
        "created_at": "datetime",
        "updated_at": "datetime"
    },
    "message": "Category retrieved successfully"
}
```

## Cart (No Authentication Required)

### View Cart
```http
GET /cart

Response:
{
    "data": {
        "items": [
            {
                "variation": {
                    "id": number,
                    "size": "string",
                    "color": "string",
                    "price": number,
                    "stock": number,
                    "product": {
                        "id": number,
                        "name_en": "string",
                        "name_ar": "string",
                        "description_en": "string",
                        "description_ar": "string",
                        "images": [
                            {
                                "id": number,
                                "url": "string",
                                "is_primary": boolean,
                                "created_at": "datetime",
                                "updated_at": "datetime"
                            }
                        ]
                    },
                    "created_at": "datetime",
                    "updated_at": "datetime"
                },
                "quantity": number
            }
        ],
        "total": number
    },
    "message": "Cart retrieved successfully"
}
```

### Add to Cart
```http
POST /cart/add
Content-Type: application/json

{
    "variation_id": number,
    "quantity": number
}

Response:
{
    "message": "Item added to cart successfully"
}
```

### Update Cart Item
```http
PUT /cart/update/{item_index}
Content-Type: application/json

{
    "quantity": number
}

Response:
{
    "message": "Cart updated successfully"
}
```

### Remove from Cart
```http
DELETE /cart/remove/{item_index}

Response:
{
    "message": "Item removed from cart successfully"
}
```

## Orders

### Create Order (No Authentication Required)
```http
POST /orders
Content-Type: application/json

{
    "shipping_name": "string",
    "shipping_email": "string",
    "shipping_phone": "string",
    "shipping_address": "string",
    "payment_method": "cash_on_delivery" | "card",
    "notes": "string" (optional)
}

Response:
{
    "data": {
        "id": number,
        "order_number": "string",
        "status": "pending" | "processing" | "shipped" | "delivered" | "cancelled",
        "payment_status": "pending" | "paid" | "failed",
        "subtotal": number,
        "total": number,
        "shipping_name": "string",
        "shipping_email": "string",
        "shipping_phone": "string",
        "shipping_address": "string",
        "payment_method": "string",
        "notes": "string",
        "items": [
            {
                "id": number,
                "variation": {
                    "id": number,
                    "size": "string",
                    "color": "string",
                    "price": number,
                    "product": {
                        "id": number,
                        "name_en": "string",
                        "name_ar": "string",
                        "images": [
                            {
                                "id": number,
                                "url": "string",
                                "is_primary": boolean
                            }
                        ]
                    }
                },
                "quantity": number,
                "price": number,
                "total": number
            }
        ],
        "created_at": "datetime",
        "updated_at": "datetime"
    },
    "message": "Order created successfully"
}
```

### List Orders (Requires Authentication)
```http
GET /orders
Authorization: Bearer {token}

Response:
{
    "data": [
        {
            "id": number,
            "order_number": "string",
            "status": "pending" | "processing" | "shipped" | "delivered" | "cancelled",
            "payment_status": "pending" | "paid" | "failed",
            "subtotal": number,
            "total": number,
            "shipping_name": "string",
            "shipping_email": "string",
            "shipping_phone": "string",
            "shipping_address": "string",
            "payment_method": "string",
            "notes": "string",
            "items": [
                {
                    "id": number,
                    "variation": {
                        "id": number,
                        "size": "string",
                        "color": "string",
                        "price": number,
                        "product": {
                            "id": number,
                            "name_en": "string",
                            "name_ar": "string",
                            "images": [
                                {
                                    "id": number,
                                    "url": "string",
                                    "is_primary": boolean
                                }
                            ]
                        }
                    },
                    "quantity": number,
                    "price": number,
                    "total": number
                }
            ],
            "created_at": "datetime",
            "updated_at": "datetime"
        }
    ],
    "message": "Orders retrieved successfully"
}
```

### Get Single Order (Requires Authentication)
```http
GET /orders/{order_id}
Authorization: Bearer {token}

Response:
{
    "data": {
        "id": number,
        "order_number": "string",
        "status": "pending" | "processing" | "shipped" | "delivered" | "cancelled",
        "payment_status": "pending" | "paid" | "failed",
        "subtotal": number,
        "total": number,
        "shipping_name": "string",
        "shipping_email": "string",
        "shipping_phone": "string",
        "shipping_address": "string",
        "payment_method": "string",
        "notes": "string",
        "items": [
            {
                "id": number,
                "variation": {
                    "id": number,
                    "size": "string",
                    "color": "string",
                    "price": number,
                    "product": {
                        "id": number,
                        "name_en": "string",
                        "name_ar": "string",
                        "images": [
                            {
                                "id": number,
                                "url": "string",
                                "is_primary": boolean
                            }
                        ]
                    }
                },
                "quantity": number,
                "price": number,
                "total": number
            }
        ],
        "created_at": "datetime",
        "updated_at": "datetime"
    },
    "message": "Order retrieved successfully"
}
```

## Language

### Switch Language
```http
POST /language/switch
Content-Type: application/json

{
    "locale": "en" | "ar"
}

Response:
{
    "message": "Language switched successfully",
    "locale": "string"
}
```

## Admin APIs (Requires Authentication + Admin Role)

### Products Management
```http
GET    /admin/products
POST   /admin/products
GET    /admin/products/{id}
PUT    /admin/products/{id}
DELETE /admin/products/{id}
```

### Categories Management
```http
GET    /admin/categories
POST   /admin/categories
GET    /admin/categories/{id}
PUT    /admin/categories/{id}
DELETE /admin/categories/{id}
```

### Orders Management
```http
GET /admin/orders
GET /admin/orders/{order_id}
PUT /admin/orders/{order_id}/status
PUT /admin/orders/{order_id}/payment-status
```

## Error Responses

The API returns error responses in the following format:
```json
{
    "message": "Error message",
    "errors": {
        "field": [
            "Error description"
        ]
    }
}
```

Common HTTP status codes:
- 200: Success
- 400: Bad Request
- 401: Unauthorized
- 403: Forbidden
- 404: Not Found
- 422: Validation Error
- 500: Server Error 