<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Order;
use Illuminate\Http\Request;
use App\Services\PackagingSlipService;

class OrderController extends Controller
{
    public function index()
    {
        $orders = Order::with(['user', 'items'])->latest()->paginate(10);
        return view('admin.orders.index', compact('orders'));
    }

    public function show(Order $order)
    {
        $order->load(['user', 'items.product', 'items.variation']);
        return view('admin.orders.show', compact('order'));
    }

    public function update(Request $request, Order $order)
    {
        // Implementation will be added later
    }

    public function updateStatus(Request $request, Order $order)
    {
        $request->validate([
            'status' => 'required|in:pending,processing,completed,cancelled'
        ]);

        $order->update([
            'status' => $request->status
        ]);

        return response()->json([
            'data' => $order->load(['user', 'items.variation.product']),
            'message' => 'Order status updated successfully'
        ]);
    }

    public function updatePaymentStatus(Request $request, Order $order)
    {
        $request->validate([
            'payment_status' => 'required|in:pending,paid,failed'
        ]);

        $order->update([
            'payment_status' => $request->payment_status
        ]);

        return response()->json([
            'data' => $order->load(['user', 'items.variation.product']),
            'message' => 'Order payment status updated successfully'
        ]);
    }

    public function packagingSlip(Order $order)
    {
        $packagingSlipService = new PackagingSlipService();
        $pdfPath = $packagingSlipService->generateSlip($order);

        return response()->file(storage_path('app/' . $pdfPath));
    }
} 