<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class SubcategoryController extends Controller
{
    public function index(Category $category)
    {
        $subcategories = $category->children()->orderBy('order')->get();
        return view('admin.categories.subcategories.index', compact('category', 'subcategories'));
    }

    public function create(Category $category)
    {
        $categories = Category::whereNull('parent_id')->get();
        return view('admin.categories.subcategories.create', compact('category', 'categories'));
    }

    public function store(Request $request, Category $category)
    {
        $validated = $request->validate([
            'parent_id' => 'required|exists:categories,id',
            'name_en' => 'required|string|max:255',
            'name_ar' => 'required|string|max:255',
            'description_en' => 'nullable|string',
            'description_ar' => 'nullable|string',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'order' => 'nullable|integer',
            'is_featured' => 'boolean',
        ]);

        $validated['slug'] = Str::slug($validated['name_en']);

        if ($request->hasFile('image')) {
            $validated['image'] = $request->file('image')->store('categories', 'public');
        }

        $subcategory = $category->children()->create($validated);

        return redirect()
            ->route('admin.categories.subcategories.index', $category)
            ->with('success', 'Subcategory created successfully.');
    }

    public function edit(Category $category, Category $subcategory)
    {
        $categories = Category::whereNull('parent_id')->get();
        return view('admin.categories.subcategories.edit', compact('category', 'subcategory', 'categories'));
    }

    public function update(Request $request, Category $category, Category $subcategory)
    {
        $validated = $request->validate([
            'parent_id' => 'required|exists:categories,id',
            'name_en' => 'required|string|max:255',
            'name_ar' => 'required|string|max:255',
            'description_en' => 'nullable|string',
            'description_ar' => 'nullable|string',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'order' => 'nullable|integer',
            'is_featured' => 'boolean',
        ]);

        $validated['slug'] = Str::slug($validated['name_en']);

        if ($request->hasFile('image')) {
            // Delete old image if exists
            if ($subcategory->image) {
                Storage::disk('public')->delete($subcategory->image);
            }
            $validated['image'] = $request->file('image')->store('categories', 'public');
        }

        $subcategory->update($validated);

        return redirect()
            ->route('admin.categories.subcategories.index', $category)
            ->with('success', 'Subcategory updated successfully.');
    }

    public function destroy(Category $category, Category $subcategory)
    {
        if ($subcategory->image) {
            Storage::disk('public')->delete($subcategory->image);
        }

        $subcategory->delete();

        return redirect()
            ->route('admin.categories.subcategories.index', $category)
            ->with('success', 'Subcategory deleted successfully.');
    }
} 