<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\VariationType;
use App\Models\VariationOptionLookup;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class VariationOptionController extends Controller
{
    public function index()
    {
        $options = VariationOptionLookup::with('type')
            ->orderBy('order')
            ->paginate(10);

        return view('admin.variations.options.index', compact('options'));
    }

    public function create()
    {
        $variationTypes = VariationType::where('is_active', true)->orderBy('name_en')->get();
        return view('admin.variations.options.create', compact('variationTypes'));
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'variation_type_id' => 'required|exists:variation_types,id',
            'value_en' => 'required|string|max:255',
            'value_ar' => 'required|string|max:255',
            'code' => 'nullable|string|max:255',
            'order' => 'required|integer|min:0',
            'is_active' => 'boolean'
        ]);

        DB::table('variation_option_lookups')->insert([
            'variation_type_id' => $validated['variation_type_id'],
            'value_en' => $validated['value_en'],
            'value_ar' => $validated['value_ar'],
            'code' => $validated['code'],
            'order' => $validated['order'],
            'is_active' => $request->boolean('is_active', true),
            'created_at' => now(),
            'updated_at' => now(),
        ]);

        return redirect()->route('admin.variations.options.index')
            ->with('success', 'Variation option created successfully.');
    }

    public function edit($id)
    {
        $option = DB::table('variation_option_lookups')->where('id', $id)->first();
        if (!$option) {
            return redirect()->route('admin.variations.options.index')
                ->with('error', 'Variation option not found.');
        }

        $variationTypes = VariationType::where('is_active', true)->orderBy('name_en')->get();
        return view('admin.variations.options.edit', compact('option', 'variationTypes'));
    }

    public function update(Request $request, $id)
    {
        $validated = $request->validate([
            'variation_type_id' => 'required|exists:variation_types,id',
            'value_en' => 'required|string|max:255',
            'value_ar' => 'required|string|max:255',
            'code' => 'nullable|string|max:255',
            'order' => 'required|integer|min:0',
            'is_active' => 'boolean'
        ]);

        DB::table('variation_option_lookups')
            ->where('id', $id)
            ->update([
                'variation_type_id' => $validated['variation_type_id'],
                'value_en' => $validated['value_en'],
                'value_ar' => $validated['value_ar'],
                'code' => $validated['code'],
                'order' => $validated['order'],
                'is_active' => $request->boolean('is_active', true),
                'updated_at' => now(),
            ]);

        return redirect()->route('admin.variations.options.index')
            ->with('success', 'Variation option updated successfully.');
    }

    public function destroy($id)
    {
        DB::table('variation_option_lookups')->where('id', $id)->delete();
        return redirect()->route('admin.variations.options.index')
            ->with('success', 'Variation option deleted successfully.');
    }
}