<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\VariationType;
use Illuminate\Http\Request;

class VariationTypeController extends Controller
{
    public function index()
    {
        $types = VariationType::with('options')->get();
        return view('admin.variations.types.index', compact('types'));
    }

    public function create()
    {
        return view('admin.variations.types.create');
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'name_en' => 'required|string|max:255',
            'name_ar' => 'required|string|max:255',
            'slug' => 'required|string|max:255|unique:variation_types',
            'is_active' => 'boolean',
        ]);

        VariationType::create($validated);

        return redirect()->route('admin.variations.types.index')
            ->with('success', 'Variation type created successfully.');
    }

    public function edit(VariationType $type)
    {
        return view('admin.variations.types.edit', compact('type'));
    }

    public function update(Request $request, VariationType $type)
    {
        $validated = $request->validate([
            'name_en' => 'required|string|max:255',
            'name_ar' => 'required|string|max:255',
            'slug' => 'required|string|max:255|unique:variation_types,slug,' . $type->id,
            'is_active' => 'boolean',
        ]);

        $type->update($validated);

        return redirect()->route('admin.variations.types.index')
            ->with('success', 'Variation type updated successfully.');
    }

    public function destroy(VariationType $type)
    {
        $type->delete();

        return redirect()->route('admin.variations.types.index')
            ->with('success', 'Variation type deleted successfully.');
    }
} 