<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Product;
use App\Models\ProductVariation;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class CartController extends Controller
{
    public function index()
    {
        $cart = Session::get('cart', []);
        $items = [];
        $total = 0;

        foreach ($cart as $item) {
            $variation = ProductVariation::with('product')
                ->find($item['variation_id']);

            if ($variation) {
                $items[] = [
                    'variation' => $variation,
                    'quantity' => $item['quantity']
                ];
                $total += $variation->product->current_price * $item['quantity'];
            }
        }

        return response()->json([
            'data' => [
                'items' => $items,
                'total' => $total
            ],
            'message' => 'Cart retrieved successfully'
        ]);
    }

    public function add(Request $request)
    {
        $request->validate([
            'variation_id' => 'required|exists:product_variations,id',
            'quantity' => 'required|integer|min:1'
        ]);

        $variation = ProductVariation::find($request->variation_id);

        if ($variation->stock < $request->quantity) {
            return response()->json([
                'message' => 'Insufficient stock'
            ], 400);
        }

        $cart = Session::get('cart', []);
        $found = false;

        foreach ($cart as &$item) {
            if ($item['variation_id'] == $request->variation_id) {
                $item['quantity'] += $request->quantity;
                $found = true;
                break;
            }
        }

        if (!$found) {
            $cart[] = [
                'variation_id' => $request->variation_id,
                'quantity' => $request->quantity
            ];
        }

        Session::put('cart', $cart);

        return response()->json([
            'message' => 'Item added to cart successfully'
        ]);
    }

    public function update(Request $request, $index)
    {
        $request->validate([
            'quantity' => 'required|integer|min:1'
        ]);

        $cart = Session::get('cart', []);

        if (!isset($cart[$index])) {
            return response()->json([
                'message' => 'Item not found in cart'
            ], 404);
        }

        $variation = ProductVariation::find($cart[$index]['variation_id']);

        if ($variation->stock < $request->quantity) {
            return response()->json([
                'message' => 'Insufficient stock'
            ], 400);
        }

        $cart[$index]['quantity'] = $request->quantity;
        Session::put('cart', $cart);

        return response()->json([
            'message' => 'Cart updated successfully'
        ]);
    }

    public function remove($index)
    {
        $cart = Session::get('cart', []);

        if (!isset($cart[$index])) {
            return response()->json([
                'message' => 'Item not found in cart'
            ], 404);
        }

        array_splice($cart, $index, 1);
        Session::put('cart', $cart);

        return response()->json([
            'message' => 'Item removed from cart successfully'
        ]);
    }
} 