<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Product;
use Illuminate\Http\Request;

class ProductController extends Controller
{
    public function index(Request $request)
    {
        $query = Product::with(['category', 'variations', 'images'])
            ->where('is_active', true);

        // Filter by category
        if ($request->has('category_id')) {
            $query->where('category_id', $request->category_id);
        }

        // Filter by featured
        if ($request->has('featured')) {
            $query->where('is_featured', true);
        }

        // Filter by search term
        if ($request->has('search')) {
            $search = $request->search;
            $query->where(function($q) use ($search) {
                $q->where('name_en', 'like', "%{$search}%")
                  ->orWhere('name_ar', 'like', "%{$search}%");
            });
        }

        $products = $query->paginate(12);

        return response()->json([
            'data' => $products,
            'message' => 'Products retrieved successfully'
        ]);
    }

    public function show(Product $product)
    {
        $product->load(['category', 'variations', 'images']);

        return response()->json([
            'data' => $product,
            'message' => 'Product retrieved successfully'
        ]);
    }

    public function featured()
    {
        $products = Product::with(['category', 'variations', 'images'])
            ->where('is_active', true)
            ->where('is_featured', true)
            ->take(8)
            ->get();

        return response()->json([
            'data' => $products,
            'message' => 'Featured products retrieved successfully'
        ]);
    }
} 