<?php

namespace App\Http\Controllers;

use App\Models\Message;
use App\Models\MessageReaction;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Broadcast;

class ChatController extends Controller
{
    public function toggleReaction(Message $message, Request $request)
    {
        $request->validate([
            'emoji' => 'required|string|max:8'
        ]);

        $reaction = MessageReaction::firstOrNew([
            'message_id' => $message->id,
            'user_id' => auth()->id(),
            'emoji' => $request->emoji
        ]);

        if ($reaction->exists) {
            $reaction->delete();
        } else {
            $reaction->save();
        }

        // Get updated reactions
        $reactions = MessageReaction::where('message_id', $message->id)
            ->selectRaw('emoji, COUNT(*) as count')
            ->groupBy('emoji')
            ->pluck('count', 'emoji')
            ->toArray();

        // Get user's reactions
        $userReactions = MessageReaction::where('message_id', $message->id)
            ->where('user_id', auth()->id())
            ->pluck('emoji')
            ->toArray();

        // Broadcast the reaction update
        broadcast(new MessageReaction($message->id, $reactions, $userReactions))->toOthers();

        return response()->json([
            'reactions' => $reactions,
            'userReactions' => $userReactions
        ]);
    }

    public function editMessage(Message $message, Request $request)
    {
        if ($message->sender_id !== auth()->id()) {
            return response()->json(['error' => 'Unauthorized'], 403);
        }

        $request->validate([
            'message' => 'required|string|max:1000'
        ]);

        $message->update([
            'message' => $request->message,
            'edited_at' => now()
        ]);

        broadcast(new MessageEdited($message->id, $request->message, $message->edited_at))->toOthers();

        return response()->json($message);
    }

    public function deleteMessage(Message $message)
    {
        if ($message->sender_id !== auth()->id()) {
            return response()->json(['error' => 'Unauthorized'], 403);
        }

        $message->delete();

        broadcast(new MessageDeleted($message->id))->toOthers();

        return response()->json(['success' => true]);
    }
} 