<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Str;

class ActivityLog extends Model
{
    protected $fillable = [
        'user_id',
        'action',
        'model_type',
        'model_id',
        'description',
        'old_values',
        'new_values',
        'ip_address',
        'user_agent',
    ];

    protected $casts = [
        'old_values' => 'array',
        'new_values' => 'array',
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function subject()
    {
        return $this->morphTo('model');
    }

    public function getActionColorAttribute()
    {
        return match($this->action) {
            'create' => 'green',
            'update' => 'yellow',
            'delete' => 'red',
            default => 'gray',
        };
    }

    public function getModelNameAttribute()
    {
        return $this->model_type;
    }

    public function getChangesAttribute()
    {
        if ($this->action === 'create') {
            return $this->new_values;
        } elseif ($this->action === 'delete') {
            return $this->old_values;
        } else {
            $changes = [];
            if ($this->old_values && $this->new_values) {
                foreach ($this->new_values as $key => $newValue) {
                    $oldValue = $this->old_values[$key] ?? null;
                    if ($oldValue !== $newValue) {
                        $changes[$key] = [
                            'old' => $oldValue,
                            'new' => $newValue
                        ];
                    }
                }
            }
            return $changes;
        }
    }
}
