<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Message extends Model
{
    use HasFactory;

    protected $fillable = [
        'sender_id',
        'receiver_id',
        'message',
        'type',
        'file_path',
        'reply_to_id',
        'seen_at',
        'edited_at'
    ];

    protected $dates = [
        'seen_at',
    ];

    protected $casts = [
        'seen_at' => 'datetime',
        'edited_at' => 'datetime'
    ];

    // Sender relationship
    public function sender(): BelongsTo
    {
        return $this->belongsTo(User::class, 'sender_id');
    }

    // Receiver relationship
    public function receiver(): BelongsTo
    {
        return $this->belongsTo(User::class, 'receiver_id');
    }

    // Reply relationship
    public function replyTo(): BelongsTo
    {
        return $this->belongsTo(Message::class, 'reply_to_id');
    }

    // Helper: is this message a reply?
    public function isReply(): bool
    {
        return !is_null($this->reply_to_id);
    }

    // Helper: get media URL
    public function getMediaUrlAttribute(): ?string
    {
        return $this->file_path ? asset('storage/' . $this->file_path) : null;
    }

    public function order(): BelongsTo
    {
        return $this->belongsTo(Order::class);
    }

    public function markAsSeen(): void
    {
        $this->update(['seen_at' => now()]);
    }

    public function isUnread(): bool
    {
        return is_null($this->seen_at);
    }

    public function reactions()
    {
        return $this->hasMany(MessageReaction::class);
    }
} 