<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Traits\LogsActivity;

class ProductVariation extends Model
{
    use HasFactory, LogsActivity;

    protected $fillable = [
        'product_id',
        'color_en',
        'color_ar',
        'color_code',
        'size_en',
        'size_ar',
        'stock',
        'sku'
    ];

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function images()
    {
        return $this->hasMany(ProductImage::class);
    }

    public function orderItems()
    {
        return $this->hasMany(OrderItem::class);
    }

    public function getColorAttribute()
    {
        return app()->getLocale() === 'ar' ? $this->color_ar : $this->color_en;
    }

    public function getSizeAttribute()
    {
        return app()->getLocale() === 'ar' ? $this->size_ar : $this->size_en;
    }

    public function getIsLowStockAttribute()
    {
        return $this->stock <= $this->product->stock_threshold;
    }
} 