<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Variation extends Model
{
    use HasFactory;

    protected $fillable = [
        'product_id',
        'sku',
        'barcode',
        'price',
        'discount_price',
        'discount_start',
        'discount_end',
        'stock',
        'stock_threshold',
        'weight',
        'image',
        'is_active',
    ];

    protected $casts = [
        'price' => 'decimal:2',
        'discount_price' => 'decimal:2',
        'discount_start' => 'datetime',
        'discount_end' => 'datetime',
        'stock' => 'integer',
        'stock_threshold' => 'integer',
        'weight' => 'decimal:2',
        'is_active' => 'boolean',
    ];

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function options()
    {
        return $this->belongsToMany(VariationOptionLookup::class, 'variation_option_values', 'variation_id', 'variation_option_id');
    }

    public function getOption($type)
    {
        return $this->options()->whereHas('type', function($query) use ($type) {
            $query->where('slug', $type);
        })->first();
    }

    public function getSizeAttribute()
    {
        return $this->getOption('size');
    }

    public function getColorAttribute()
    {
        return $this->getOption('color');
    }

    public function getMaterialAttribute()
    {
        return $this->getOption('material');
    }

    public function getPriceAttribute($value)
    {
        return (float) $value;
    }

    public function getDiscountPriceAttribute($value)
    {
        return $value ? (float) $value : null;
    }

    public function getIsDiscountedAttribute()
    {
        if (!$this->discount_price || !$this->discount_start || !$this->discount_end) {
            return false;
        }

        $now = now();
        return $now->between($this->discount_start, $this->discount_end);
    }

    public function getFinalPriceAttribute()
    {
        return $this->is_discounted ? $this->discount_price : $this->price;
    }
} 