<?php

namespace App\Notifications;

use App\Models\Order;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class OrderAlert extends Notification implements ShouldQueue
{
    use Queueable;

    public function __construct(
        protected Order $order,
        protected string $alertType,
        protected string $message
    ) {
    }

    public function via($notifiable): array
    {
        return ['mail', 'database'];
    }

    public function toMail($notifiable): MailMessage
    {
        return (new MailMessage)
            ->subject("Order Alert: {$this->message}")
            ->greeting("Hello {$notifiable->name},")
            ->line("We have an alert regarding your order #{$this->order->order_number}:")
            ->line($this->message)
            ->line("Current Status: {$this->order->status->label()}")
            ->when($this->order->tracking_number, function ($message) {
                return $message->line("Tracking Number: {$this->order->tracking_number}")
                    ->action('Track Order', $this->order->tracking_url);
            })
            ->action('View Order', route('orders.show', $this->order))
            ->line('Please contact our support team if you need assistance.');
    }

    public function toArray($notifiable): array
    {
        return [
            'order_id' => $this->order->id,
            'order_number' => $this->order->order_number,
            'alert_type' => $this->alertType,
            'message' => $this->message,
            'status' => $this->order->status->value,
            'tracking_number' => $this->order->tracking_number,
            'tracking_url' => $this->order->tracking_url,
        ];
    }
} 