<?php

namespace App\Notifications;

use App\Models\Order;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class OrderStatusUpdated extends Notification implements ShouldQueue
{
    use Queueable;

    public function __construct(protected Order $order)
    {
    }

    public function via($notifiable): array
    {
        return ['mail', 'database'];
    }

    public function toMail($notifiable): MailMessage
    {
        $message = (new MailMessage)
            ->subject("Order #{$this->order->order_number} Status Updated")
            ->greeting("Hello {$notifiable->name},")
            ->line("Your order #{$this->order->order_number} status has been updated to: {$this->order->status->label()}");

        if ($this->order->tracking_number) {
            $message->line("Tracking Number: {$this->order->tracking_number}");
            
            if ($this->order->tracking_url) {
                $message->action('Track Your Order', $this->order->tracking_url);
            }
        }

        $message->line('You can view your order details by clicking the button below.')
            ->action('View Order', route('orders.show', $this->order))
            ->line('Thank you for shopping with us!');

        return $message;
    }

    public function toArray($notifiable): array
    {
        return [
            'order_id' => $this->order->id,
            'order_number' => $this->order->order_number,
            'status' => $this->order->status->value,
            'status_label' => $this->order->status->label(),
            'tracking_number' => $this->order->tracking_number,
            'tracking_url' => $this->order->tracking_url,
        ];
    }
} 