<?php

namespace App\Services;

use App\Models\Log;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Request;

class LogService
{
    public static function log($action, Model $model, $description = null, $oldValues = null, $newValues = null)
    {
        return Log::create([
            'user_id' => Auth::id(),
            'action' => $action,
            'model_type' => class_basename($model),
            'model_id' => $model->id,
            'old_values' => $oldValues,
            'new_values' => $newValues,
            'ip_address' => Request::ip(),
            'user_agent' => Request::userAgent(),
            'description' => $description
        ]);
    }

    public static function logCreate(Model $model, $description = null)
    {
        return self::log('create', $model, $description, null, $model->toArray());
    }

    public static function logUpdate(Model $model, $oldValues, $newValues, $description = null)
    {
        return self::log('update', $model, $description, $oldValues, $newValues);
    }

    public static function logDelete(Model $model, $description = null)
    {
        return self::log('delete', $model, $description, $model->toArray(), null);
    }
} 