<?php

namespace App\Services;

use App\Models\Order;
use Illuminate\Support\Facades\Storage;
use Endroid\QrCode\Builder\Builder;
use Endroid\QrCode\Writer\SvgWriter;
use Barryvdh\DomPDF\Facade\Pdf;

class PackagingSlipService
{
    public function generateSlip(Order $order): string
    {
        // Generate QR code with order details
        $qrData = [
            'order_id' => $order->id,
            'order_number' => $order->order_number,
            'tracking_number' => $order->tracking_number,
            'items' => $order->items->map(fn($item) => [
                'name' => $item->product->name,
                'quantity' => $item->quantity,
                'sku' => $item->variation->sku,
            ])->toArray(),
        ];

        $result = Builder::create()
            ->writer(new SvgWriter())
            ->writerOptions([])
            ->data(json_encode($qrData))
            ->size(200)
            ->margin(10)
            ->build();

        // Ensure temp directory exists
        $tempDir = storage_path('app/temp');
        if (!file_exists($tempDir)) {
            mkdir($tempDir, 0755, true);
        }

        $qrPath = "temp/qr-{$order->id}.svg";
        $result->saveToFile(storage_path('app/' . $qrPath));

        // Generate PDF
        $pdf = PDF::loadView('admin.orders.packaging-slip', [
            'order' => $order,
            'qrCode' => Storage::url($qrPath),
        ]);

        // Save PDF
        $pdfPath = "packaging-slips/order-{$order->id}.pdf";
        Storage::put($pdfPath, $pdf->output());

        // Clean up temporary QR code
        Storage::delete($qrPath);

        return $pdfPath;
    }

    public function getSlipUrl(Order $order): ?string
    {
        $path = "packaging-slips/order-{$order->id}.pdf";
        
        if (Storage::exists($path)) {
            return Storage::url($path);
        }

        return null;
    }
} 