<?php

namespace App\Traits;

use App\Models\ActivityLog;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;

trait LogsActivity
{
    protected static function bootLogsActivity()
    {
        static::created(function ($model) {
            self::logActivity('create', $model);
        });

        static::updated(function ($model) {
            self::logActivity('update', $model);
        });

        static::deleted(function ($model) {
            self::logActivity('delete', $model);
        });
    }

    protected static function logActivity($action, $model)
    {
        $modelName = class_basename($model);
        $modelId = $model->id;
        
        // Prepare old and new values based on action
        $oldValues = null;
        $newValues = null;
        
        if ($action === 'update') {
            $changes = $model->getDirty();
            $oldValues = array_intersect_key($model->getOriginal(), $changes);
            $newValues = array_intersect_key($model->getAttributes(), $changes);
        } elseif ($action === 'delete') {
            $oldValues = $model->getAttributes();
        } else { // create
            $newValues = $model->getAttributes();
        }

        try {
            ActivityLog::create([
                'user_id' => Auth::id() ?? 1,
                'action' => $action,
                'model_type' => $modelName,
                'model_id' => $modelId,
                'old_values' => $oldValues,
                'new_values' => $newValues,
                'ip_address' => request()->ip(),
                'user_agent' => request()->userAgent(),
                'description' => ucfirst($action) . 'd ' . $modelName . ' #' . $modelId,
                'created_at' => now(),
            ]);
        } catch (\Exception $e) {
            \Log::error('Failed to create activity log: ' . $e->getMessage());
        }
    }
} 