<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Facades\DB;

return new class extends Migration
{
    public function up()
    {
        Schema::table('products', function (Blueprint $table) {
            // First check if the column exists
            if (Schema::hasColumn('products', 'brand_id')) {
                // Check if foreign key exists before trying to drop it
                $foreignKeys = DB::select("
                    SELECT CONSTRAINT_NAME 
                    FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE 
                    WHERE TABLE_NAME = 'products' 
                    AND COLUMN_NAME = 'brand_id' 
                    AND CONSTRAINT_NAME != 'PRIMARY'
                ");
                
                if (!empty($foreignKeys)) {
                    $table->dropForeign(['brand_id']);
                }
                
                $table->dropColumn('brand_id');
            }
        });
    }

    public function down()
    {
        Schema::table('products', function (Blueprint $table) {
            if (!Schema::hasColumn('products', 'brand_id')) {
                $table->foreignId('brand_id')->nullable()->constrained()->onDelete('set null');
            }
        });
    }
}; 