<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Facades\DB;

return new class extends Migration
{
    public function up()
    {
        Schema::create('variation_option_lookups', function (Blueprint $table) {
            $table->id();
            $table->foreignId('variation_type_id')->constrained('variation_types')->onDelete('cascade');
            $table->string('value_en');
            $table->string('value_ar');
            $table->string('code')->nullable();
            $table->integer('order')->default(0);
            $table->boolean('is_active')->default(true);
            $table->timestamps();
        });

        // Insert default color options
        DB::table('variation_option_lookups')->insert([
            ['variation_type_id' => 1, 'value_en' => 'Red', 'value_ar' => 'أحمر', 'code' => '#FF0000', 'order' => 1],
            ['variation_type_id' => 1, 'value_en' => 'Blue', 'value_ar' => 'أزرق', 'code' => '#0000FF', 'order' => 2],
            ['variation_type_id' => 1, 'value_en' => 'Green', 'value_ar' => 'أخضر', 'code' => '#00FF00', 'order' => 3],
            ['variation_type_id' => 1, 'value_en' => 'Black', 'value_ar' => 'أسود', 'code' => '#000000', 'order' => 4],
            ['variation_type_id' => 1, 'value_en' => 'White', 'value_ar' => 'أبيض', 'code' => '#FFFFFF', 'order' => 5],
        ]);

        // Insert default size options
        DB::table('variation_option_lookups')->insert([
            ['variation_type_id' => 2, 'value_en' => 'XS', 'value_ar' => 'XS', 'code' => null, 'order' => 1],
            ['variation_type_id' => 2, 'value_en' => 'S', 'value_ar' => 'S', 'code' => null, 'order' => 2],
            ['variation_type_id' => 2, 'value_en' => 'M', 'value_ar' => 'M', 'code' => null, 'order' => 3],
            ['variation_type_id' => 2, 'value_en' => 'L', 'value_ar' => 'L', 'code' => null, 'order' => 4],
            ['variation_type_id' => 2, 'value_en' => 'XL', 'value_ar' => 'XL', 'code' => null, 'order' => 5],
            ['variation_type_id' => 2, 'value_en' => 'XXL', 'value_ar' => 'XXL', 'code' => null, 'order' => 6],
        ]);

        // Insert default material options
        DB::table('variation_option_lookups')->insert([
            ['variation_type_id' => 3, 'value_en' => 'Cotton', 'value_ar' => 'قطن', 'code' => null, 'order' => 1],
            ['variation_type_id' => 3, 'value_en' => 'Polyester', 'value_ar' => 'بوليستر', 'code' => null, 'order' => 2],
            ['variation_type_id' => 3, 'value_en' => 'Wool', 'value_ar' => 'صوف', 'code' => null, 'order' => 3],
            ['variation_type_id' => 3, 'value_en' => 'Silk', 'value_ar' => 'حرير', 'code' => null, 'order' => 4],
            ['variation_type_id' => 3, 'value_en' => 'Linen', 'value_ar' => 'كتان', 'code' => null, 'order' => 5],
        ]);
    }

    public function down()
    {
        Schema::dropIfExists('variation_option_lookups');
    }
}; 