<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\Message;
use App\Models\User;
use Carbon\Carbon;

class ChatSeeder extends Seeder
{
    public function run(): void
    {
        // Get admin user
        $admin = User::where('is_admin', true)->first();
        
        // Get some regular users
        $users = User::where('is_admin', false)->take(5)->get();
        
        if (!$admin || $users->isEmpty()) {
            $this->command->error('Please run UserSeeder first to create users!');
            return;
        }

        $sampleMessages = [
            'Hello! How can I help you today?',
            'I have a question about my order',
            'Sure, what would you like to know?',
            'When will my order be delivered?',
            'Let me check that for you...',
            'Your order is scheduled for delivery tomorrow',
            'Thank you for the information!',
            'You\'re welcome! Is there anything else I can help you with?',
            'No, that\'s all. Have a great day!',
            'You too! Feel free to contact us if you need anything else.'
        ];

        foreach ($users as $user) {
            // Create a conversation between admin and each user
            $timestamp = Carbon::now()->subHours(rand(1, 24));
            
            foreach ($sampleMessages as $index => $message) {
                // Alternate between admin and user sending messages
                $sender = $index % 2 === 0 ? $admin : $user;
                $receiver = $index % 2 === 0 ? $user : $admin;
                
                Message::create([
                    'sender_id' => $sender->id,
                    'receiver_id' => $receiver->id,
                    'message' => $message,
                    'type' => 'text',
                    'created_at' => $timestamp->addMinutes(rand(1, 5)),
                    'seen_at' => $index % 2 === 0 ? null : $timestamp->copy()->addMinutes(1)
                ]);
            }
        }

        $this->command->info('Chat messages seeded successfully!');
    }
} 