<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Faker\Factory as Faker;

class DatabaseSeeder extends Seeder
{
    public function run(): void
    {
        $this->call([
            AdminUserSeeder::class,
            CategorySeeder::class,
            ProductSeeder::class,
            VariationSeeder::class,
            CustomerSeeder::class,
            OrderSeeder::class,
            DeliveryCompanySeeder::class,
            ChatSeeder::class,
            LogSeeder::class,
        ]);

        // Calculate and seed total sales (sum of all order totals)
        $totalSales = DB::table('orders')->sum('total');
        DB::table('total_sales')->insert([
            'total_amount' => $totalSales,
            'created_at' => now(),
            'updated_at' => now(),
        ]);

        // Calculate and seed total spent by each customer
        $users = DB::table('users')->pluck('id');
        foreach ($users as $userId) {
            $totalSpent = DB::table('orders')->where('user_id', $userId)->sum('total');
            DB::table('customer_spent')->insert([
                'user_id' => $userId,
                'total_spent' => $totalSpent,
                'created_at' => now(),
                'updated_at' => now(),
            ]);
        }

        // Calculate and seed total revenue (same as total sales in this case)
        DB::table('total_revenue')->insert([
            'total_amount' => $totalSales,
            'created_at' => now(),
            'updated_at' => now(),
        ]);

        // Seed subcategories (50 subcategories, each linked to a random parent category)
        $faker = Faker::create();
        $parentCategories = DB::table('categories')->pluck('id');
        for ($i = 0; $i < 50; $i++) {
            DB::table('categories')->insert([
                'name_en' => $faker->word,
                'name_ar' => $faker->word,
                'slug' => Str::slug($faker->unique()->words(2, true)),
                'description_en' => $faker->sentence,
                'description_ar' => $faker->sentence,
                'parent_id' => $faker->randomElement($parentCategories),
                'created_at' => now(),
                'updated_at' => now(),
            ]);
        }
    }
}
