<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\DeliveryCompany;

class DeliveryCompanySeeder extends Seeder
{
    public function run(): void
    {
        $companies = [
            [
                'name' => 'Aramex',
                'code' => 'aramex',
                'is_active' => true,
                'config' => [
                    'tracking_url_template' => 'https://www.aramex.com/track/{tracking_number}',
                    'api_version' => 'v1',
                    'supported_countries' => ['AE', 'SA', 'KW', 'QA', 'BH', 'OM'],
                ]
            ],
            [
                'name' => 'DHL Express',
                'code' => 'dhl',
                'is_active' => true,
                'config' => [
                    'tracking_url_template' => 'https://www.dhl.com/track/{tracking_number}',
                    'api_version' => 'v2',
                    'supported_countries' => ['AE', 'SA', 'KW', 'QA', 'BH', 'OM'],
                ]
            ],
            [
                'name' => 'FedEx',
                'code' => 'fedex',
                'is_active' => true,
                'config' => [
                    'tracking_url_template' => 'https://www.fedex.com/tracking?tracknumbers={tracking_number}',
                    'api_version' => 'v1',
                    'supported_countries' => ['AE', 'SA', 'KW', 'QA', 'BH', 'OM'],
                ]
            ],
            [
                'name' => 'Local Delivery',
                'code' => 'local',
                'is_active' => true,
                'config' => [
                    'tracking_url_template' => null,
                    'supported_countries' => ['AE'],
                ]
            ]
        ];

        foreach ($companies as $company) {
            DeliveryCompany::updateOrCreate(
                ['code' => $company['code']],
                $company
            );
        }
    }
} 