<?php

namespace Database\Seeders;

use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;
use App\Models\Log;
use App\Models\User;
use Carbon\Carbon;

class LogSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        // Get the first admin user
        $user = User::where('is_admin', true)->first();

        if (!$user) {
            return;
        }

        $actions = ['create', 'update', 'delete'];
        $models = ['Product', 'Order', 'Category', 'Customer', 'Variation'];
        
        // Create 50 sample logs
        for ($i = 0; $i < 50; $i++) {
            $action = $actions[array_rand($actions)];
            $model = $models[array_rand($models)];
            $modelId = rand(1, 100);
            
            $oldValues = null;
            $newValues = null;
            
            if ($action === 'update') {
                $oldValues = [
                    'name' => 'Old ' . $model . ' Name',
                    'status' => 'inactive',
                    'price' => rand(1000, 5000) / 100,
                ];
                
                $newValues = [
                    'name' => 'New ' . $model . ' Name',
                    'status' => 'active',
                    'price' => rand(1000, 5000) / 100,
                ];
            } elseif ($action === 'delete') {
                $oldValues = [
                    'name' => 'Deleted ' . $model . ' Name',
                    'status' => 'active',
                    'price' => rand(1000, 5000) / 100,
                ];
            } else {
                $newValues = [
                    'name' => 'New ' . $model . ' Name',
                    'status' => 'active',
                    'price' => rand(1000, 5000) / 100,
                ];
            }

            Log::create([
                'user_id' => $user->id,
                'action' => $action,
                'model_type' => $model,
                'model_id' => $modelId,
                'old_values' => $oldValues,
                'new_values' => $newValues,
                'ip_address' => '127.0.0.1',
                'user_agent' => 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36',
                'description' => ucfirst($action) . 'd ' . $model . ' #' . $modelId,
                'created_at' => Carbon::now()->subHours(rand(1, 48)),
            ]);
        }
    }
}
