<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\Product;
use App\Models\User;
use Illuminate\Support\Str;
use Faker\Factory as Faker;

class OrderSeeder extends Seeder
{
    public function run(): void
    {
        $faker = Faker::create();
        
        // Get customers
        $customers = User::where('is_admin', false)->get();
        if ($customers->isEmpty()) {
            return;
        }

        $statuses = ['pending', 'processing', 'completed', 'cancelled'];
        $paymentMethods = ['cash_on_delivery', 'card'];

        // Create 50 orders
        for ($i = 0; $i < 50; $i++) {
            $customer = $customers->random();
            $orderNumber = 'ORD-' . strtoupper(Str::random(8));

            $order = Order::updateOrCreate(
                ['order_number' => $orderNumber],
                [
                    'user_id' => $customer->id,
                    'status' => $statuses[array_rand($statuses)],
                    'payment_method' => $paymentMethods[array_rand($paymentMethods)],
                    'payment_status' => rand(0, 1) ? 'paid' : 'pending',
                    'shipping_name' => $customer->name,
                    'shipping_email' => $customer->email,
                    'shipping_phone' => $customer->phone,
                    'shipping_address' => $customer->address,
                    'subtotal' => 0,
                    'discount' => 0,
                    'total' => 0,
                    'notes' => $faker->optional()->sentence,
                ]
            );

            // Remove existing items for this order to prevent duplicates if seeder is re-run
            $order->items()->delete();

            // Create order items
            $products = Product::with('variations')->get();
            $total = 0;

            // Add 1-5 items per order
            $numItems = rand(1, 5);
            $selectedProducts = $products->random($numItems);

            foreach ($selectedProducts as $product) {
                $variations = $product->variations;
                
                if ($variations->isEmpty()) {
                    continue;
                }
                
                $variation = $variations->random();
                $quantity = rand(1, 3);
                $price = rand(10, 100);
                $itemTotal = $price * $quantity;
                $total += $itemTotal;

                OrderItem::create([
                    'order_id' => $order->id,
                    'product_id' => $product->id,
                    'variation_id' => $variation->id,
                    'quantity' => $quantity,
                    'price' => $price,
                    'total' => $itemTotal,
                ]);
            }

            // Update order totals
            $order->update([
                'subtotal' => $total,
                'total' => $total,
            ]);
        }
    }
} 