<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\Product;
use App\Models\ProductImage;
use Illuminate\Support\Str;

class ProductSeeder extends Seeder
{
    public function run(): void
    {
        $products = [
            [
                'name_en' => 'Classic White T-Shirt',
                'name_ar' => 'تي شيرت أبيض كلاسيكي',
                'description_en' => 'Premium cotton t-shirt with a comfortable fit',
                'description_ar' => 'تي شيرت قطن فاخر بتصميم مريح',
                'category_id' => 1,
                'is_featured' => true,
                'is_active' => true,
            ],
            [
                'name_en' => 'Slim Fit Jeans',
                'name_ar' => 'جينز ضيق',
                'description_en' => 'Modern slim fit jeans with stretch comfort',
                'description_ar' => 'جينز ضيق عصري مع راحة التمدد',
                'category_id' => 1,
                'is_featured' => true,
                'is_active' => true,
            ],
            [
                'name_en' => 'Summer Dress',
                'name_ar' => 'فستان صيفي',
                'description_en' => 'Light and flowy summer dress',
                'description_ar' => 'فستان صيفي خفيف وفضفاض',
                'category_id' => 2,
                'is_featured' => true,
                'is_active' => true,
            ],
            [
                'name_en' => 'Leather Belt',
                'name_ar' => 'حزام جلد',
                'description_en' => 'Genuine leather belt with classic buckle',
                'description_ar' => 'حزام جلد طبيعي مع مشبك كلاسيكي',
                'category_id' => 3,
                'is_featured' => false,
                'is_active' => true,
            ],
            [
                'name_en' => 'Running Shoes',
                'name_ar' => 'أحذية رياضية',
                'description_en' => 'Comfortable running shoes with good support',
                'description_ar' => 'أحذية رياضية مريحة مع دعم جيد',
                'category_id' => 4,
                'is_featured' => true,
                'is_active' => true,
            ],
        ];

        foreach ($products as $product) {
            $slug = Str::slug($product['name_en']);
            $newProduct = Product::updateOrCreate(
                ['slug' => $slug],
                [
                    'name_en' => $product['name_en'],
                    'name_ar' => $product['name_ar'],
                    'description_en' => $product['description_en'],
                    'description_ar' => $product['description_ar'],
                    'category_id' => $product['category_id'],
                    'is_featured' => $product['is_featured'],
                    'is_active' => $product['is_active'],
                ]
            );

            // Create product images
            for ($i = 0; $i < 3; $i++) {
                ProductImage::updateOrCreate(
                    [
                        'product_id' => $newProduct->id,
                        'order' => $i,
                    ],
                    [
                        'image_path' => 'products/default-product.jpg',
                        'is_primary' => $i === 0,
                    ]
                );
            }
        }
    }
} 