<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\Product;
use App\Models\ProductVariation;
use App\Models\VariationType;
use App\Models\VariationOptionLookup;
use Illuminate\Support\Str;

class VariationSeeder extends Seeder
{
    public function run(): void
    {
        // Create Variation Types
        $variationTypes = [
            ['name_en' => 'Size', 'name_ar' => 'المقاس', 'slug' => 'size'],
            ['name_en' => 'Color', 'name_ar' => 'اللون', 'slug' => 'color'],
            ['name_en' => 'Material', 'name_ar' => 'المادة', 'slug' => 'material'],
        ];

        foreach ($variationTypes as $type) {
            VariationType::updateOrCreate(
                ['slug' => $type['slug']],
                [
                    'name_en' => $type['name_en'],
                    'name_ar' => $type['name_ar'],
                    'is_active' => true,
                ]
            );
        }

        // Create Variation Options
        $sizeOptions = ['XS', 'S', 'M', 'L', 'XL', 'XXL'];
        $colorOptions = [
            ['en' => 'Black', 'ar' => 'أسود', 'code' => '#000000'],
            ['en' => 'White', 'ar' => 'أبيض', 'code' => '#FFFFFF'],
            ['en' => 'Red', 'ar' => 'أحمر', 'code' => '#FF0000'],
            ['en' => 'Blue', 'ar' => 'أزرق', 'code' => '#0000FF'],
            ['en' => 'Green', 'ar' => 'أخضر', 'code' => '#008000'],
        ];
        $materialOptions = [
            ['en' => 'Cotton', 'ar' => 'قطن'],
            ['en' => 'Polyester', 'ar' => 'بوليستر'],
            ['en' => 'Wool', 'ar' => 'صوف'],
            ['en' => 'Leather', 'ar' => 'جلد'],
            ['en' => 'Silk', 'ar' => 'حرير'],
        ];

        $sizeType = VariationType::where('slug', 'size')->first();
        $colorType = VariationType::where('slug', 'color')->first();
        $materialType = VariationType::where('slug', 'material')->first();

        foreach ($sizeOptions as $size) {
            VariationOptionLookup::updateOrCreate(
                [
                    'variation_type_id' => $sizeType->id,
                    'code' => $size,
                ],
                [
                    'value_en' => $size,
                    'value_ar' => $size,
                    'order' => array_search($size, $sizeOptions),
                    'is_active' => true,
                ]
            );
        }

        foreach ($colorOptions as $index => $color) {
            VariationOptionLookup::updateOrCreate(
                [
                    'variation_type_id' => $colorType->id,
                    'code' => $color['code'],
                ],
                [
                    'value_en' => $color['en'],
                    'value_ar' => $color['ar'],
                    'order' => $index,
                    'is_active' => true,
                ]
            );
        }

        foreach ($materialOptions as $index => $material) {
            VariationOptionLookup::updateOrCreate(
                [
                    'variation_type_id' => $materialType->id,
                    'code' => Str::slug($material['en']),
                ],
                [
                    'value_en' => $material['en'],
                    'value_ar' => $material['ar'],
                    'order' => $index,
                    'is_active' => true,
                ]
            );
        }

        // Create variations for each product
        $products = Product::all();
        $sizes = VariationOptionLookup::where('variation_type_id', $sizeType->id)->get();
        $colors = VariationOptionLookup::where('variation_type_id', $colorType->id)->get();

        foreach ($products as $product) {
            foreach ($sizes as $size) {
                foreach ($colors as $color) {
                    ProductVariation::updateOrCreate(
                        [
                            'product_id' => $product->id,
                            'size_en' => $size->value_en,
                            'color_en' => $color->value_en,
                        ],
                        [
                            'color_ar' => $color->value_ar,
                            'color_code' => $color->code,
                            'size_ar' => $size->value_ar,
                            'stock' => rand(0, 50),
                            'sku' => sprintf('PROD%d-S%d-C%d',
                                $product->id,
                                $size->id,
                                $color->id
                            ),
                        ]
                    );
                }
            }
        }
    }
} 