@extends('admin.layouts.app')

@section('content')
<div class="flex h-[90vh] bg-white rounded-lg shadow overflow-hidden">
    <!-- Loading State -->
    <div id="loadingState" class="fixed inset-0 bg-white bg-opacity-75 flex items-center justify-center z-50 hidden">
        <div class="animate-spin rounded-full h-12 w-12 border-b-2 border-indigo-600"></div>
    </div>

    <!-- Error State -->
    <div id="errorState" class="fixed inset-0 bg-white bg-opacity-75 flex items-center justify-center z-50 hidden">
        <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative" role="alert">
            <strong class="font-bold">Error!</strong>
            <span id="errorMessage" class="block sm:inline"></span>
            <button onclick="retryLoading()" class="mt-2 bg-red-500 text-white px-4 py-2 rounded hover:bg-red-600">
                Retry
            </button>
        </div>
    </div>

    <!-- Sidebar: Conversations -->
    <aside class="w-1/3 border-r border-gray-200 flex flex-col">
        <div class="p-4 border-b border-gray-200">
            <div class="relative">
                <input type="text" 
                    id="searchInput"
                    placeholder="Search users..." 
                    class="w-full px-3 py-2 rounded bg-gray-100 text-gray-900" 
                />
                <!-- Search Results Dropdown -->
                <div id="searchResults" class="absolute z-10 w-full mt-1 bg-white rounded-lg shadow-lg border border-gray-200 hidden">
                </div>
            </div>
        </div>
        <div class="flex-1 overflow-y-auto">
            <ul id="conversation-list">
            </ul>
        </div>
    </aside>

    <!-- Main Chat Area -->
    <section id="chatArea" class="flex-1 flex flex-col hidden">
        <!-- Chat Header -->
        <header class="flex items-center justify-between px-6 py-4 border-b border-gray-200">
            <div class="flex items-center gap-4">
                <a href="{{ route('admin.dashboard') }}" class="text-gray-500 hover:text-gray-700">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M10 19l-7-7m0 0l7-7m-7 7h18"></path>
                    </svg>
                </a>
                <div class="relative">
                    <div id="userAvatar" class="h-10 w-10 rounded-full bg-gray-300 flex items-center justify-center text-lg font-bold text-gray-700"></div>
                    <div id="userStatus" class="absolute bottom-0 right-0 h-3 w-3 bg-green-500 rounded-full border-2 border-white hidden"></div>
                </div>
                <div>
                    <div id="userName" class="font-semibold text-gray-900"></div>
                    <div id="userStatusText" class="text-xs text-gray-500"></div>
                </div>
            </div>
            <div class="flex items-center gap-2">
                <button onclick="toggleEmojiPicker()" class="p-2 rounded hover:bg-gray-100">
                    <svg class="w-5 h-5 text-gray-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.828 14.828a4 4 0 01-5.656 0M9 10h.01M15 10h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
                    </svg>
                </button>
            </div>
        </header>

        <!-- Chat Thread -->
        <div id="chatThread" class="flex-1 overflow-y-auto px-6 py-4 space-y-4 bg-gray-50">
        </div>

        <!-- Chat Input -->
        <footer class="p-4 border-t border-gray-200 bg-white">
            <form id="messageForm" class="flex items-center gap-2">
                <button type="button" onclick="triggerFileInput()" title="Attach file" class="p-2 rounded hover:bg-gray-100">
                    <svg class="w-5 h-5 text-gray-500" fill="none" stroke="currentColor" stroke-width="2" viewBox="0 0 24 24">
                        <path stroke-linecap="round" stroke-linejoin="round" d="M15.172 7l-6.586 6.586a2 2 0 102.828 2.828l7.07-7.07a4 4 0 10-5.656-5.657l-8.486 8.485a6 6 0 108.485 8.486L19 13"></path>
                    </svg>
                </button>
                <input type="text" 
                    id="messageInput"
                    placeholder="Type a message..." 
                    class="flex-1 px-3 py-2 rounded bg-gray-100 text-gray-900" 
                    autocomplete="off" 
                />
                <input type="file" id="fileInput" class="hidden" onchange="handleFile(event)" accept="image/*,video/*,audio/*" />
                <button type="submit" class="ml-2 px-4 py-2 bg-indigo-600 text-white rounded hover:bg-indigo-700">Send</button>
            </form>
        </footer>
    </section>
</div>

<!-- Image Modal -->
<div id="imageModal" class="fixed inset-0 z-50 flex items-center justify-center bg-black bg-opacity-70 hidden">
    <div class="relative">
        <img id="modalImage" class="max-h-[80vh] rounded shadow-lg" />
        <button onclick="closeImageModal()" class="absolute top-2 right-2 text-white bg-black bg-opacity-50 rounded-full p-2 hover:bg-opacity-75">
            <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path>
            </svg>
        </button>
    </div>
</div>

<!-- Emoji Picker -->
<div id="emojiPicker" class="fixed bottom-20 right-4 bg-white rounded-lg shadow-lg p-4 w-64 hidden">
    <div class="grid grid-cols-8 gap-1" id="emojiGrid">
    </div>
</div>

@push('scripts')
<script>
let selectedUser = null;
let messages = [];
let conversations = [];
let pollingInterval = null;
const emojis = ['😀', '😂', '😊', '❤️', '👍', '🎉', '🔥', '👏', '🙏', '🤔', '😎', '😢', '😡', '🤮', '💩', '👻', '🤖', '👽', '👾', '🤖', '🎮', '🎲', '🎯', '🎨', '🎭', '🎪', '🎟️', '🎫', '🎗️', '🏆', '🎖️', '🥇', '🥈', '🥉'];
let currentPage = 1;
let isLoading = false;
let hasMoreResults = true;

// Initialize chat
document.addEventListener('DOMContentLoaded', function() {
    loadConversations();
    setupEventListeners();
    populateEmojiGrid();
});

function setupEventListeners() {
    document.getElementById('searchInput').addEventListener('input', debounce(searchUsers, 300));
    document.getElementById('messageForm').addEventListener('submit', sendMessage);
    document.addEventListener('click', function(e) {
        if (!e.target.closest('#emojiPicker')) {
            document.getElementById('emojiPicker').classList.add('hidden');
        }
        if (!e.target.closest('#searchResults') && !e.target.closest('#searchInput')) {
            document.getElementById('searchResults').classList.add('hidden');
        }
    });
}

function debounce(func, wait) {
    let timeout;
    return function executedFunction(...args) {
        const later = () => {
            clearTimeout(timeout);
            func(...args);
        };
        clearTimeout(timeout);
        timeout = setTimeout(later, wait);
    };
}

async function loadConversations() {
    showLoading();
    try {
        const response = await fetch('/admin/chat/conversations', {
            method: 'GET',
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}'
            }
        });
        if (!response.ok) throw new Error('Failed to load conversations');
        conversations = await response.json();
        // Sort conversations by last_message_time in descending order
        conversations.sort((a, b) => new Date(b.last_message_time) - new Date(a.last_message_time));
        renderConversations(conversations);
    } catch (error) {
        showError('Failed to load conversations');
        console.error('Load conversations error:', error);
    } finally {
        hideLoading();
    }
}

function renderConversations(conversations) {
    const container = document.getElementById('conversation-list');
    container.innerHTML = conversations.map(conversation => `
        <li onclick="selectConversation(${JSON.stringify(conversation).replace(/"/g, '&quot;')})" 
            class="px-4 py-3 flex items-center gap-3 hover:bg-gray-100 cursor-pointer">
            <div class="relative">
                <div class="h-10 w-10 rounded-full bg-gray-300 flex items-center justify-center text-lg font-bold text-gray-700">
                    ${conversation.name[0]}
                </div>
                ${conversation.online ? `
                    <div class="absolute bottom-0 right-0 h-3 w-3 bg-green-500 rounded-full border-2 border-white"></div>
                ` : ''}
            </div>
            <div class="flex-1 min-w-0">
                <div class="flex justify-between items-center">
                    <div class="font-semibold text-gray-900">${conversation.name}</div>
                    <div class="text-xs text-gray-500">${formatTime(conversation.last_message_time)}</div>
                </div>
                <div class="flex justify-between items-center">
                    <div class="text-xs text-gray-500 truncate">${conversation.last_message}</div>
                    ${conversation.unread > 0 ? `
                        <span class="inline-block min-w-[20px] text-xs bg-indigo-600 text-white rounded-full px-2 py-0.5 text-center">
                            ${conversation.unread}
                        </span>
                    ` : ''}
                </div>
            </div>
        </li>
    `).join('');
}

async function selectConversation(user) {
    selectedUser = user;
    document.getElementById('chatArea').classList.remove('hidden');
    document.getElementById('userName').textContent = user.name;
    document.getElementById('userAvatar').textContent = user.name[0];
    document.getElementById('userStatus').classList.toggle('hidden', !user.online);
    document.getElementById('userStatusText').textContent = user.online ? 'Online' : 'Offline';
    
    // Start polling for new messages
    if (pollingInterval) clearInterval(pollingInterval);
    loadMessages();
    pollingInterval = setInterval(loadMessages, 5000);
}

async function loadMessages() {
    if (!selectedUser) return;
    
    try {
        const response = await fetch(`/admin/chat/thread/${selectedUser.id}`, {
            method: 'GET',
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}'
            }
        });
        
        if (!response.ok) {
            throw new Error('Failed to load messages');
        }
        
        const data = await response.json();
        messages = data;
        renderMessages();
    } catch (error) {
        console.error('Error loading messages:', error);
        showError('Failed to load messages');
    }
}

function renderMessages() {
    const container = document.getElementById('chatThread');
    const groupedMessages = groupMessagesByDate(messages);
    
    container.innerHTML = Object.entries(groupedMessages).map(([date, msgs]) => `
        <div class="flex items-center justify-center my-4">
            <div class="px-4 py-1 bg-gray-200 rounded-full text-xs text-gray-600">${formatDate(date)}</div>
        </div>
        ${msgs.map(message => `
            <div class="flex gap-3 items-end group ${message.sender_id === {{ auth()->id() }} ? 'justify-end' : 'justify-start'}">
                <div class="h-8 w-8 rounded-full bg-gray-300 flex items-center justify-center text-sm font-bold text-gray-700">
                    ${message.sender_id === {{ auth()->id() }} ? 'Me' : selectedUser.name[0]}
                </div>
                <div class="relative group">
                    ${message.type === 'text' ? `
                        <div class="bg-indigo-100 text-gray-900 rounded-lg px-4 py-2 max-w-lg">
                            <div class="text-sm">${message.message}</div>
                            <div class="flex items-center gap-2 mt-1">
                                <div class="text-xs text-gray-500">${formatTime(message.created_at)}</div>
                                ${message.sender_id === {{ auth()->id() }} ? `
                                    <div class="text-xs ${message.seen_at ? 'text-blue-600' : 'text-gray-400'}">
                                        <svg class="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
                                        </svg>
                                    </div>
                                ` : ''}
                            </div>
                        </div>
                    ` : `
                        <div class="bg-indigo-100 rounded-lg px-2 py-2 max-w-xs">
                            ${message.type === 'image' ? `
                                <img src="${message.media_url}" class="rounded cursor-pointer max-h-40" onclick="openImage('${message.media_url}')" />
                            ` : message.type === 'video' ? `
                                <video controls class="rounded max-h-40">
                                    <source src="${message.media_url}" type="video/mp4">
                                </video>
                            ` : message.type === 'voice' ? `
                                <audio controls src="${message.media_url}" class="w-full"></audio>
                            ` : ''}
                            <div class="flex items-center gap-2 mt-1">
                                <div class="text-xs text-gray-500">${formatTime(message.created_at)}</div>
                                ${message.sender_id === {{ auth()->id() }} ? `
                                    <div class="text-xs ${message.seen_at ? 'text-blue-600' : 'text-gray-400'}">
                                        <svg class="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
                                        </svg>
                                    </div>
                                ` : ''}
                            </div>
                        </div>
                    `}
                    <div class="absolute right-0 top-0 hidden group-hover:flex gap-1">
                        <button onclick="replyToMessage(${message.id})" class="p-1 bg-gray-800 text-white rounded-full hover:bg-gray-700">
                            <svg class="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M3 10h10a8 8 0 018 8v2M3 10l6 6m-6-6l6-6"></path>
                            </svg>
                        </button>
                    </div>
                </div>
            </div>
        `).join('')}
    `).join('');
    
    scrollToBottom();
}

async function sendMessage(e) {
    e.preventDefault();
    if (!selectedUser) return;
    
    const input = document.getElementById('messageInput');
    const message = input.value.trim();
    if (!message) return;
    
    const formData = new FormData();
    formData.append('receiver_id', selectedUser.id);
    formData.append('message', message);
    formData.append('type', 'text');
    formData.append('_token', '{{ csrf_token() }}'); // Add CSRF token to form data
    
    try {
        const response = await fetch('/admin/chat/send', {
            method: 'POST',
            body: formData,
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}',
                'Accept': 'application/json'
            }
        });
        
        if (!response.ok) {
            const errorData = await response.json();
            throw new Error(errorData.message || 'Failed to send message');
        }
        
        const newMessage = await response.json();
        messages.push(newMessage);
        renderMessages();
        input.value = '';
        
        // Update conversation in the list
        const conversationIndex = conversations.findIndex(c => c.id === selectedUser.id);
        if (conversationIndex !== -1) {
            conversations[conversationIndex].last_message = message;
            conversations[conversationIndex].last_message_time = new Date().toISOString();
            // Sort conversations again
            conversations.sort((a, b) => new Date(b.last_message_time) - new Date(a.last_message_time));
            renderConversations(conversations);
        }
    } catch (error) {
        showError(error.message || 'Failed to send message');
        console.error('Send message error:', error);
    }
}

async function searchUsers() {
    const query = document.getElementById('searchInput').value.trim();
    if (!query) {
        document.getElementById('searchResults').classList.add('hidden');
        return;
    }
    
    try {
        const response = await fetch(`/admin/chat/search?q=${encodeURIComponent(query)}`, {
            method: 'GET',
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}'
            }
        });
        if (!response.ok) throw new Error('Failed to search users');
        const users = await response.json();
        
        const container = document.getElementById('searchResults');
        if (users.length === 0) {
            container.innerHTML = `
                <div class="px-4 py-2 text-gray-500">
                    No users found
                </div>
            `;
        } else {
            container.innerHTML = users.map(user => `
                <div onclick="startConversation(${JSON.stringify(user).replace(/"/g, '&quot;')})" 
                    class="px-4 py-2 hover:bg-gray-100 cursor-pointer">
                    <div class="font-medium text-gray-900">${user.name}</div>
                    <div class="text-sm text-gray-500">${user.email}</div>
                </div>
            `).join('');
        }
        
        container.classList.remove('hidden');
    } catch (error) {
        console.error('Search users error:', error);
        showError('Failed to search users');
    }
}

function startConversation(user) {
    document.getElementById('searchResults').classList.add('hidden');
    document.getElementById('searchInput').value = '';
    
    // Check if conversation already exists
    const existingConversation = conversations.find(c => c.id === user.id);
    if (!existingConversation) {
        // Add new conversation to the beginning of the list
        conversations.unshift({
            id: user.id,
            name: user.name,
            last_message: '',
            last_message_time: new Date().toISOString(),
            unread: 0,
            online: false
        });
        // Sort conversations
        conversations.sort((a, b) => new Date(b.last_message_time) - new Date(a.last_message_time));
        renderConversations(conversations);
    }
    
    selectConversation(user);
}

async function handleFile(event) {
    const file = event.target.files[0];
    if (!file || !selectedUser) return;
    
    showLoading();
    const formData = new FormData();
    formData.append('file', file);
    formData.append('receiver_id', selectedUser.id);
    
    // Set message based on file type
    const fileType = getFileType(file);
    formData.append('type', fileType);
    
    // Set a default message based on file type
    let defaultMessage = '';
    switch(fileType) {
        case 'image':
            defaultMessage = 'Sent an image';
            break;
        case 'video':
            defaultMessage = 'Sent a video';
            break;
        case 'voice':
            defaultMessage = 'Sent a voice message';
            break;
        default:
            defaultMessage = 'Sent a file';
    }
    formData.append('message', defaultMessage);
    formData.append('_token', '{{ csrf_token() }}');
    
    try {
        const response = await fetch('/admin/chat/send', {
            method: 'POST',
            body: formData,
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}',
                'Accept': 'application/json'
            }
        });
        
        if (!response.ok) {
            const errorData = await response.json();
            throw new Error(errorData.message || 'Failed to upload file');
        }
        
        const message = await response.json();
        messages.push(message);
        renderMessages();
        event.target.value = '';
        
        // Update conversation in the list
        const conversationIndex = conversations.findIndex(c => c.id === selectedUser.id);
        if (conversationIndex !== -1) {
            conversations[conversationIndex].last_message = defaultMessage;
            conversations[conversationIndex].last_message_time = new Date().toISOString();
            // Sort conversations again
            conversations.sort((a, b) => new Date(b.last_message_time) - new Date(a.last_message_time));
            renderConversations(conversations);
        }
    } catch (error) {
        console.error('Error uploading file:', error);
        showError(error.message || 'Failed to upload file');
    } finally {
        hideLoading();
    }
}

function getFileType(file) {
    const type = file.type.split('/')[0];
    if (type === 'image') return 'image';
    if (type === 'video') return 'video';
    if (file.type.startsWith('audio/')) return 'voice';
    return 'file';
}

function triggerFileInput() {
    document.getElementById('fileInput').click();
}

function openImage(url) {
    const modal = document.getElementById('imageModal');
    const image = document.getElementById('modalImage');
    image.src = url;
    modal.classList.remove('hidden');
}

function closeImageModal() {
    document.getElementById('imageModal').classList.add('hidden');
}

function toggleEmojiPicker() {
    document.getElementById('emojiPicker').classList.toggle('hidden');
}

function populateEmojiGrid() {
    document.getElementById('emojiGrid').innerHTML = emojis.map(emoji => `
        <button onclick="addEmoji('${emoji}')" class="p-1 hover:bg-gray-100 rounded text-lg">
            ${emoji}
        </button>
    `).join('');
}

function addEmoji(emoji) {
    const input = document.getElementById('messageInput');
    input.value += emoji;
    document.getElementById('emojiPicker').classList.add('hidden');
}

function groupMessagesByDate(messages) {
    return messages.reduce((groups, message) => {
        const date = new Date(message.created_at).toDateString();
        if (!groups[date]) groups[date] = [];
        groups[date].push(message);
        return groups;
    }, {});
}

function formatTime(timestamp) {
    if (!timestamp) return '';
    const date = new Date(timestamp);
    return date.toLocaleTimeString([], { hour: 'numeric', minute: '2-digit' });
}

function formatDate(timestamp) {
    if (!timestamp) return '';
    const date = new Date(timestamp);
    return date.toLocaleDateString([], { month: 'short', day: 'numeric' });
}

function scrollToBottom() {
    const thread = document.getElementById('chatThread');
    thread.scrollTop = thread.scrollHeight;
}

function showLoading() {
    document.getElementById('loadingState').classList.remove('hidden');
}

function hideLoading() {
    document.getElementById('loadingState').classList.add('hidden');
}

function showError(message) {
    document.getElementById('errorMessage').textContent = message;
    document.getElementById('errorState').classList.remove('hidden');
}

function retryLoading() {
    document.getElementById('errorState').classList.add('hidden');
    loadConversations();
}

function replyToMessage(messageId) {
    const message = messages.find(m => m.id === messageId);
    if (!message) return;
    
    const input = document.getElementById('messageInput');
    input.value = `Replying to: ${message.message}\n`;
    input.focus();
}
</script>
@endpush
@endsection 