@extends('admin.layouts.app')

@section('title', 'Edit Variation Option')

@section('content')
<div class="container-fluid px-4">
    <div class="bg-gradient-to-r from-blue-500/10 via-purple-500/10 to-pink-500/10 rounded-lg p-8 mb-8">
        <div class="bg-white dark:bg-gray-800 rounded-lg shadow-lg p-6">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-semibold text-gray-900 dark:text-white">Edit Variation Option</h1>
                <a href="{{ route('admin.variations.options.index') }}" class="text-blue-500 hover:text-blue-600 transition duration-200">
                    Back to List
                </a>
            </div>

            <form action="{{ route('admin.variations.options.update', $option->id) }}" method="POST" class="space-y-6">
                @csrf
                @method('PUT')

                <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <div>
                        <label for="variation_type_id" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Variation Type</label>
                        <select name="variation_type_id" id="variation_type_id" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:text-white" required>
                            <option value="">Select Type</option>
                            @foreach($variationTypes as $type)
                                <option value="{{ $type->id }}" {{ old('variation_type_id', $option->variation_type_id) == $type->id ? 'selected' : '' }}>
                                    {{ $type->name_en }}
                                </option>
                            @endforeach
                        </select>
                        @error('variation_type_id')
                            <p class="mt-1 text-sm text-red-600">{{ $message }}</p>
                        @enderror
                    </div>

                    <div>
                        <label for="order" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Display Order</label>
                        <input type="number" name="order" id="order" value="{{ old('order', $option->order) }}" min="0" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:text-white" required>
                        @error('order')
                            <p class="mt-1 text-sm text-red-600">{{ $message }}</p>
                        @enderror
                    </div>

                    <div>
                        <label for="value_en" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Value (English)</label>
                        <input type="text" name="value_en" id="value_en" value="{{ old('value_en', $option->value_en) }}" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:text-white" required>
                        @error('value_en')
                            <p class="mt-1 text-sm text-red-600">{{ $message }}</p>
                        @enderror
                    </div>

                    <div>
                        <label for="value_ar" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Value (Arabic)</label>
                        <input type="text" name="value_ar" id="value_ar" value="{{ old('value_ar', $option->value_ar) }}" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:text-white" required>
                        @error('value_ar')
                            <p class="mt-1 text-sm text-red-600">{{ $message }}</p>
                        @enderror
                    </div>

                    <div>
                        <label for="code" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Color Code (optional)</label>
                        <div class="mt-1 flex space-x-2">
                            <input type="color" name="color_picker" id="color_picker" class="h-10 w-10 rounded border border-gray-300 dark:border-gray-600" value="{{ old('code', $option->code) }}" onchange="document.getElementById('code').value = this.value">
                            <input type="text" name="code" id="code" value="{{ old('code', $option->code) }}" placeholder="#000000" class="flex-1 rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:text-white">
                        </div>
                        @error('code')
                            <p class="mt-1 text-sm text-red-600">{{ $message }}</p>
                        @enderror
                    </div>

                    <div class="flex items-center">
                        <label class="relative inline-flex items-center cursor-pointer">
                            <input type="checkbox" name="is_active" value="1" class="sr-only peer" {{ old('is_active', $option->is_active) ? 'checked' : '' }}>
                            <div class="w-11 h-6 bg-gray-200 peer-focus:outline-none peer-focus:ring-4 peer-focus:ring-blue-300 dark:peer-focus:ring-blue-800 rounded-full peer dark:bg-gray-700 peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-blue-600"></div>
                            <span class="ml-3 text-sm font-medium text-gray-900 dark:text-gray-300">Active</span>
                        </label>
                    </div>
                </div>

                <div class="flex justify-end space-x-3">
                    <a href="{{ route('admin.variations.options.index') }}" class="px-4 py-2 border border-gray-300 rounded-md text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500 dark:border-gray-600 dark:text-gray-300 dark:hover:bg-gray-700">
                        Cancel
                    </a>
                    <button type="submit" class="px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                        Update Option
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

@push('scripts')
<script>
    document.addEventListener('DOMContentLoaded', function() {
        const colorPicker = document.getElementById('color_picker');
        const codeInput = document.getElementById('code');

        // Initialize color picker with code input value if it exists
        if (codeInput.value) {
            colorPicker.value = codeInput.value;
        }

        // Update code input when color is picked
        colorPicker.addEventListener('input', function(e) {
            codeInput.value = e.target.value;
        });

        // Update color picker when code is manually entered
        codeInput.addEventListener('input', function(e) {
            if (e.target.value.match(/^#[0-9A-Fa-f]{6}$/)) {
                colorPicker.value = e.target.value;
            }
        });
    });
</script>
@endpush
@endsection 