<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\SubcategoryController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\OrderController;
use App\Http\Controllers\Admin\VariationController;
use App\Http\Controllers\Admin\DashboardController;
use App\Http\Controllers\Admin\VariationTypeController;
use App\Http\Controllers\Admin\VariationOptionController;
use App\Http\Controllers\Admin\ChatController;
use App\Http\Controllers\Admin\CustomerController;
use App\Http\Controllers\Admin\LogController;

Route::get('/', function () {
    return view('auth.login');
});

// Authentication Routes
Route::get('/login', [\App\Http\Controllers\Auth\LoginController::class, 'showLoginForm'])->name('login');
Route::post('/login', [\App\Http\Controllers\Auth\LoginController::class, 'login']);
Route::post('/logout', [\App\Http\Controllers\Auth\LoginController::class, 'logout'])->name('logout');

Route::middleware(['auth'])->group(function () {
    Route::prefix('admin')->name('admin.')->group(function () {
        Route::get('/', [DashboardController::class, 'index'])->name('dashboard');
        
        Route::resource('products', ProductController::class);
        Route::resource('categories', CategoryController::class);
        Route::resource('orders', OrderController::class);

        // Product Variations Routes
        Route::prefix('products/{product}/variations')->name('products.variations.')->group(function () {
            Route::get('/', [VariationController::class, 'index'])->name('index');
            Route::get('/create', [VariationController::class, 'create'])->name('create');
            Route::post('/', [VariationController::class, 'store'])->name('store');
            Route::get('/{variation}/edit', [VariationController::class, 'edit'])->name('edit');
            Route::put('/{variation}', [VariationController::class, 'update'])->name('update');
            Route::delete('/{variation}', [VariationController::class, 'destroy'])->name('destroy');
        });

        // Subcategories Routes
        Route::get('categories/subcategories', [CategoryController::class, 'subcategories'])->name('categories.subcategories.index');

        Route::prefix('categories/{category}/subcategories')->name('categories.subcategories.')->group(function () {
            Route::get('/', [SubcategoryController::class, 'index'])->name('index');
            Route::get('/create', [SubcategoryController::class, 'create'])->name('create');
            Route::post('/', [SubcategoryController::class, 'store'])->name('store');
            Route::get('/{subcategory}/edit', [SubcategoryController::class, 'edit'])->name('edit');
            Route::put('/{subcategory}', [SubcategoryController::class, 'update'])->name('update');
        Route::delete('/{subcategory}', [SubcategoryController::class, 'destroy'])->name('destroy');
    });
    
        // Analysis Routes
        Route::get('analysis', [\App\Http\Controllers\Admin\AnalysisController::class, 'index'])->name('analysis');
        Route::get('analysis/sales-data', [\App\Http\Controllers\Admin\AnalysisController::class, 'salesAnalysis'])->name('analysis.sales');
        Route::get('analysis/product-data', [\App\Http\Controllers\Admin\AnalysisController::class, 'productAnalysis'])->name('analysis.products');
        Route::get('analysis/customer-data', [\App\Http\Controllers\Admin\AnalysisController::class, 'customerAnalysis'])->name('analysis.customers');
        Route::get('analysis/inventory-data', [\App\Http\Controllers\Admin\AnalysisController::class, 'inventoryAnalysis'])->name('analysis.inventory');
        Route::get('analysis/export-data', [\App\Http\Controllers\Admin\AnalysisController::class, 'exportData'])->name('analysis.export');
    
        // Product Variations Routes
        Route::prefix('variations')->name('variations.')->group(function () {
            Route::get('/', [VariationController::class, 'index'])->name('index');
            Route::get('/create', [VariationController::class, 'create'])->name('create');
            Route::post('/', [VariationController::class, 'store'])->name('store');
            Route::get('/{variation}/edit', [VariationController::class, 'edit'])->name('edit');
            Route::put('/{variation}', [VariationController::class, 'update'])->name('update');
            Route::delete('/{variation}', [VariationController::class, 'destroy'])->name('destroy');

            // Variation Types Routes
            Route::prefix('types')->name('types.')->group(function () {
                Route::get('/', [VariationTypeController::class, 'index'])->name('index');
                Route::get('/create', [VariationTypeController::class, 'create'])->name('create');
                Route::post('/', [VariationTypeController::class, 'store'])->name('store');
                Route::get('/{type}/edit', [VariationTypeController::class, 'edit'])->name('edit');
                Route::put('/{type}', [VariationTypeController::class, 'update'])->name('update');
                Route::delete('/{type}', [VariationTypeController::class, 'destroy'])->name('destroy');
            });

            // Variation Options Routes
            Route::prefix('options')->name('options.')->group(function () {
                Route::get('/', [VariationOptionController::class, 'index'])->name('index');
                Route::get('/create', [VariationOptionController::class, 'create'])->name('create');
                Route::post('/', [VariationOptionController::class, 'store'])->name('store');
                Route::get('/{option}/edit', [VariationOptionController::class, 'edit'])->name('edit');
                Route::put('/{option}', [VariationOptionController::class, 'update'])->name('update');
                Route::delete('/{option}', [VariationOptionController::class, 'destroy'])->name('destroy');
            });
        });

        // AJAX route for fetching subcategories
        Route::get('/categories/{category}/subcategories', [CategoryController::class, 'getSubcategories'])->name('categories.subcategories');

        // Chat routes
        Route::prefix('chat')->name('chat.')->group(function () {
            Route::get('/', [ChatController::class, 'index'])->name('index');
            Route::get('/conversations', [ChatController::class, 'conversations'])->name('conversations');
            Route::get('/thread/{userId}', [ChatController::class, 'thread'])->name('thread');
            Route::post('/send', [ChatController::class, 'send'])->name('send');
            Route::get('/search', [ChatController::class, 'search'])->name('search');
            Route::delete('/messages/{messageId}', [ChatController::class, 'deleteMessage'])->name('messages.delete');
            Route::post('/messages/{messageId}/reactions', [ChatController::class, 'toggleReaction'])->name('messages.reactions');
        });

        // Customer Routes
        Route::resource('customers', CustomerController::class);

        // Order Routes
        Route::prefix('orders')->name('orders.')->group(function () {
            Route::get('/', [OrderController::class, 'index'])->name('index');
            Route::get('/{order}', [OrderController::class, 'show'])->name('show');
            Route::put('/{order}/status', [OrderController::class, 'updateStatus'])->name('status.update');
            Route::put('/{order}/payment-status', [OrderController::class, 'updatePaymentStatus'])->name('payment-status.update');
            Route::get('/{order}/packaging-slip', [OrderController::class, 'packagingSlip'])->name('packaging-slip');
        });

        // Logs
        Route::get('/logs', [LogController::class, 'index'])->name('logs.index');
        Route::get('/logs/{log}', [LogController::class, 'show'])->name('logs.show');

        // Chat search endpoint
        Route::get('/chat/search', [ChatController::class, 'search'])->name('chat.search');

        // Activity Logs
        Route::get('logs', [LogController::class, 'index'])->name('logs.index');

        // New routes for total sales, total revenue, and total spent
        Route::get('total-sales', [DashboardController::class, 'totalSales'])->name('dashboard.total_sales');
        Route::get('total-revenue', [DashboardController::class, 'totalRevenue'])->name('dashboard.total_revenue');
        Route::get('total-spent', [DashboardController::class, 'totalSpent'])->name('dashboard.total_spent');
    });
});
